# coding: utf-8

"""
    Rapidata Asset API

    The API for the Rapidata Asset service

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class RapidIssue(str, Enum):
    """
    A streamlined enum representing common issues.
    """

    """
    allowed enum values
    """
    OTHER = 'Other'
    CANNOTSUBMIT = 'CannotSubmit'
    NOASSET = 'NoAsset'
    INAPPROPRIATE = 'Inappropriate'
    NOCORRECTOPTION = 'NoCorrectOption'
    WRONGLANGUAGE = 'WrongLanguage'
    DONOTUNDERSTAND = 'DoNotUnderstand'
    DONOTCARE = 'DoNotCare'
    NOTSEEOPTIONSORMEDIADIDNTLOAD = 'NotSeeOptionsOrMediaDidntLoad'
    MYANSWERISCORRECT = 'MyAnswerIsCorrect'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of RapidIssue from a JSON string"""
        return cls(json.loads(json_str))


